# 1C discharge from full

Discharge lithium-ion battery from full charge at 1C, using the initial conditions from the paper

> Xu, Shanshan, Chen, Kuan-Hung, Dasgupta, Neil P., Siegel, Jason B. and Stefanopoulou, Anna G. "Evolution of Dead Lithium Growth in Lithium Metal Batteries: Experimentally Validated Model of the Apparent Capacity Loss." Journal of The Electrochemical Society 166.14 (2019): A3456-A3463.

and references therein.
